@@ -13,18 +13,21 @@ Usage::
     client: AppSyncClient = session.client("appsync")
     ```
 """
+
 import sys
-from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
-from botocore.response import StreamingBody
 
 from .literals import (
     ApiCacheTypeType,
     ApiCachingBehaviorType,
     AuthenticationTypeType,
     DataSourceTypeType,
+    GraphQLApiTypeType,
+    GraphQLApiVisibilityType,
     OutputTypeType,
+    OwnershipType,
     ResolverKindType,
     TypeDefinitionFormatType,
 )
@@ -41,6 +44,9 @@ from .type_defs import (
     AdditionalAuthenticationProviderTypeDef,
     AppSyncRuntimeTypeDef,
     AssociateApiResponseTypeDef,
+    AssociateMergedGraphqlApiResponseTypeDef,
+    AssociateSourceGraphqlApiResponseTypeDef,
+    BlobTypeDef,
     CachingConfigTypeDef,
     CreateApiCacheResponseTypeDef,
     CreateApiKeyResponseTypeDef,
@@ -50,12 +56,16 @@ from .type_defs import (
     CreateGraphqlApiResponseTypeDef,
     CreateResolverResponseTypeDef,
     CreateTypeResponseTypeDef,
+    DisassociateMergedGraphqlApiResponseTypeDef,
+    DisassociateSourceGraphqlApiResponseTypeDef,
     DynamodbDataSourceConfigTypeDef,
     ElasticsearchDataSourceConfigTypeDef,
     EvaluateCodeResponseTypeDef,
     EvaluateMappingTemplateResponseTypeDef,
+    EventBridgeDataSourceConfigTypeDef,
     GetApiAssociationResponseTypeDef,
     GetApiCacheResponseTypeDef,
+    GetDataSourceIntrospectionResponseTypeDef,
     GetDataSourceResponseTypeDef,
     GetDomainNameResponseTypeDef,
     GetFunctionResponseTypeDef,
@@ -63,6 +73,7 @@ from .type_defs import (
     GetIntrospectionSchemaResponseTypeDef,
     GetResolverResponseTypeDef,
     GetSchemaCreationStatusResponseTypeDef,
+    GetSourceApiAssociationResponseTypeDef,
     GetTypeResponseTypeDef,
     HttpDataSourceConfigTypeDef,
     LambdaAuthorizerConfigTypeDef,
@@ -74,14 +85,20 @@ from .type_defs import (
     ListGraphqlApisResponseTypeDef,
     ListResolversByFunctionResponseTypeDef,
     ListResolversResponseTypeDef,
+    ListSourceApiAssociationsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    ListTypesByAssociationResponseTypeDef,
     ListTypesResponseTypeDef,
     LogConfigTypeDef,
     OpenIDConnectConfigTypeDef,
     OpenSearchServiceDataSourceConfigTypeDef,
     PipelineConfigTypeDef,
+    RdsDataApiConfigTypeDef,
     RelationalDatabaseDataSourceConfigTypeDef,
+    SourceApiAssociationConfigTypeDef,
+    StartDataSourceIntrospectionResponseTypeDef,
     StartSchemaCreationResponseTypeDef,
+    StartSchemaMergeResponseTypeDef,
     SyncConfigTypeDef,
     UpdateApiCacheResponseTypeDef,
     UpdateApiKeyResponseTypeDef,
@@ -90,11 +107,12 @@ from .type_defs import (
     UpdateFunctionResponseTypeDef,
     UpdateGraphqlApiResponseTypeDef,
     UpdateResolverResponseTypeDef,
+    UpdateSourceApiAssociationResponseTypeDef,
     UpdateTypeResponseTypeDef,
     UserPoolConfigTypeDef,
 )
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -103,7 +121,7 @@ else:
 __all__ = ("AppSyncClient",)
 
 
-class BotocoreClientError(BaseException):
+class BotocoreClientError(Exception):
     MSG_TEMPLATE: str
 
     def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
@@ -151,6 +169,40 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#associate_api)
         """
 
+    def associate_merged_graphql_api(
+        self,
+        *,
+        sourceApiIdentifier: str,
+        mergedApiIdentifier: str,
+        description: str = ...,
+        sourceApiAssociationConfig: SourceApiAssociationConfigTypeDef = ...
+    ) -> AssociateMergedGraphqlApiResponseTypeDef:
+        """
+        Creates an association between a Merged API and source API using the source
+        API's
+        identifier.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.associate_merged_graphql_api)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#associate_merged_graphql_api)
+        """
+
+    def associate_source_graphql_api(
+        self,
+        *,
+        mergedApiIdentifier: str,
+        sourceApiIdentifier: str,
+        description: str = ...,
+        sourceApiAssociationConfig: SourceApiAssociationConfigTypeDef = ...
+    ) -> AssociateSourceGraphqlApiResponseTypeDef:
+        """
+        Creates an association between a Merged API and source API using the Merged
+        API's
+        identifier.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.associate_source_graphql_api)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#associate_source_graphql_api)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
@@ -207,7 +259,8 @@ class AppSyncClient(BaseClient):
         elasticsearchConfig: ElasticsearchDataSourceConfigTypeDef = ...,
         openSearchServiceConfig: OpenSearchServiceDataSourceConfigTypeDef = ...,
         httpConfig: HttpDataSourceConfigTypeDef = ...,
-        relationalDatabaseConfig: RelationalDatabaseDataSourceConfigTypeDef = ...
+        relationalDatabaseConfig: RelationalDatabaseDataSourceConfigTypeDef = ...,
+        eventBridgeConfig: EventBridgeDataSourceConfigTypeDef = ...
     ) -> CreateDataSourceResponseTypeDef:
         """
         Creates a `DataSource` object.
@@ -259,7 +312,11 @@ class AppSyncClient(BaseClient):
         tags: Mapping[str, str] = ...,
         additionalAuthenticationProviders: Sequence[AdditionalAuthenticationProviderTypeDef] = ...,
         xrayEnabled: bool = ...,
-        lambdaAuthorizerConfig: LambdaAuthorizerConfigTypeDef = ...
+        lambdaAuthorizerConfig: LambdaAuthorizerConfigTypeDef = ...,
+        visibility: GraphQLApiVisibilityType = ...,
+        apiType: GraphQLApiTypeType = ...,
+        mergedApiExecutionRoleArn: str = ...,
+        ownerContact: str = ...
     ) -> CreateGraphqlApiResponseTypeDef:
         """
         Creates a `GraphqlApi` object.
@@ -336,7 +393,7 @@ class AppSyncClient(BaseClient):
 
     def delete_function(self, *, apiId: str, functionId: str) -> Dict[str, Any]:
         """
-        Deletes a `Function` .
+        Deletes a `Function`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.delete_function)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#delete_function)
@@ -374,6 +431,30 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#disassociate_api)
         """
 
+    def disassociate_merged_graphql_api(
+        self, *, sourceApiIdentifier: str, associationId: str
+    ) -> DisassociateMergedGraphqlApiResponseTypeDef:
+        """
+        Deletes an association between a Merged API and source API using the source
+        API's identifier and the association
+        ID.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.disassociate_merged_graphql_api)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#disassociate_merged_graphql_api)
+        """
+
+    def disassociate_source_graphql_api(
+        self, *, mergedApiIdentifier: str, associationId: str
+    ) -> DisassociateSourceGraphqlApiResponseTypeDef:
+        """
+        Deletes an association between a Merged API and source API using the Merged
+        API's identifier and the association
+        ID.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.disassociate_source_graphql_api)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#disassociate_source_graphql_api)
+        """
+
     def evaluate_code(
         self, *, runtime: AppSyncRuntimeTypeDef, code: str, context: str, function: str = ...
     ) -> EvaluateCodeResponseTypeDef:
@@ -440,6 +521,21 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#get_data_source)
         """
 
+    def get_data_source_introspection(
+        self,
+        *,
+        introspectionId: str,
+        includeModelsSDL: bool = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
+    ) -> GetDataSourceIntrospectionResponseTypeDef:
+        """
+        Retrieves the record of an existing introspection.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.get_data_source_introspection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#get_data_source_introspection)
+        """
+
     def get_domain_name(self, *, domainName: str) -> GetDomainNameResponseTypeDef:
         """
         Retrieves a custom `DomainName` object.
@@ -450,7 +546,7 @@ class AppSyncClient(BaseClient):
 
     def get_function(self, *, apiId: str, functionId: str) -> GetFunctionResponseTypeDef:
         """
-        Get a `Function` .
+        Get a `Function`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.get_function)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#get_function)
@@ -492,6 +588,16 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#get_schema_creation_status)
         """
 
+    def get_source_api_association(
+        self, *, mergedApiIdentifier: str, associationId: str
+    ) -> GetSourceApiAssociationResponseTypeDef:
+        """
+        Retrieves a `SourceApiAssociation` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.get_source_api_association)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#get_source_api_association)
+        """
+
     def get_type(
         self, *, apiId: str, typeName: str, format: TypeDefinitionFormatType
     ) -> GetTypeResponseTypeDef:
@@ -543,7 +649,12 @@ class AppSyncClient(BaseClient):
         """
 
     def list_graphql_apis(
-        self, *, nextToken: str = ..., maxResults: int = ...
+        self,
+        *,
+        nextToken: str = ...,
+        maxResults: int = ...,
+        apiType: GraphQLApiTypeType = ...,
+        owner: OwnershipType = ...
     ) -> ListGraphqlApisResponseTypeDef:
         """
         Lists your GraphQL APIs.
@@ -572,6 +683,16 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#list_resolvers_by_function)
         """
 
+    def list_source_api_associations(
+        self, *, apiId: str, nextToken: str = ..., maxResults: int = ...
+    ) -> ListSourceApiAssociationsResponseTypeDef:
+        """
+        Lists the `SourceApiAssociationSummary` data.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.list_source_api_associations)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#list_source_api_associations)
+        """
+
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags for a resource.
@@ -595,8 +716,34 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#list_types)
         """
 
+    def list_types_by_association(
+        self,
+        *,
+        mergedApiIdentifier: str,
+        associationId: str,
+        format: TypeDefinitionFormatType,
+        nextToken: str = ...,
+        maxResults: int = ...
+    ) -> ListTypesByAssociationResponseTypeDef:
+        """
+        Lists `Type` objects by the source API association ID.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.list_types_by_association)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#list_types_by_association)
+        """
+
+    def start_data_source_introspection(
+        self, *, rdsDataApiConfig: RdsDataApiConfigTypeDef = ...
+    ) -> StartDataSourceIntrospectionResponseTypeDef:
+        """
+        Creates a new introspection.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.start_data_source_introspection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#start_data_source_introspection)
+        """
+
     def start_schema_creation(
-        self, *, apiId: str, definition: Union[str, bytes, IO[Any], StreamingBody]
+        self, *, apiId: str, definition: BlobTypeDef
     ) -> StartSchemaCreationResponseTypeDef:
         """
         Adds a new schema to your GraphQL API.
@@ -605,6 +752,16 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#start_schema_creation)
         """
 
+    def start_schema_merge(
+        self, *, associationId: str, mergedApiIdentifier: str
+    ) -> StartSchemaMergeResponseTypeDef:
+        """
+        Initiates a merge operation.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.start_schema_merge)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#start_schema_merge)
+        """
+
     def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Tags a resource with user-supplied tags.
@@ -659,7 +816,8 @@ class AppSyncClient(BaseClient):
         elasticsearchConfig: ElasticsearchDataSourceConfigTypeDef = ...,
         openSearchServiceConfig: OpenSearchServiceDataSourceConfigTypeDef = ...,
         httpConfig: HttpDataSourceConfigTypeDef = ...,
-        relationalDatabaseConfig: RelationalDatabaseDataSourceConfigTypeDef = ...
+        relationalDatabaseConfig: RelationalDatabaseDataSourceConfigTypeDef = ...,
+        eventBridgeConfig: EventBridgeDataSourceConfigTypeDef = ...
     ) -> UpdateDataSourceResponseTypeDef:
         """
         Updates a `DataSource` object.
@@ -712,7 +870,9 @@ class AppSyncClient(BaseClient):
         openIDConnectConfig: OpenIDConnectConfigTypeDef = ...,
         additionalAuthenticationProviders: Sequence[AdditionalAuthenticationProviderTypeDef] = ...,
         xrayEnabled: bool = ...,
-        lambdaAuthorizerConfig: LambdaAuthorizerConfigTypeDef = ...
+        lambdaAuthorizerConfig: LambdaAuthorizerConfigTypeDef = ...,
+        mergedApiExecutionRoleArn: str = ...,
+        ownerContact: str = ...
     ) -> UpdateGraphqlApiResponseTypeDef:
         """
         Updates a `GraphqlApi` object.
@@ -745,6 +905,22 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#update_resolver)
         """
 
+    def update_source_api_association(
+        self,
+        *,
+        associationId: str,
+        mergedApiIdentifier: str,
+        description: str = ...,
+        sourceApiAssociationConfig: SourceApiAssociationConfigTypeDef = ...
+    ) -> UpdateSourceApiAssociationResponseTypeDef:
+        """
+        Updates some of the configuration choices of a particular source API
+        association.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.update_source_api_association)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#update_source_api_association)
+        """
+
     def update_type(
         self, *, apiId: str, typeName: str, format: TypeDefinitionFormatType, definition: str = ...
     ) -> UpdateTypeResponseTypeDef:
