@@ -11,9 +11,10 @@ Usage::
     data: ApiCacheStatusType = "AVAILABLE"
     ```
 """
+
 import sys
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -28,9 +29,12 @@ __all__ = (
     "AuthorizationTypeType",
     "ConflictDetectionTypeType",
     "ConflictHandlerTypeType",
+    "DataSourceIntrospectionStatusType",
     "DataSourceTypeType",
     "DefaultActionType",
     "FieldLogLevelType",
+    "GraphQLApiTypeType",
+    "GraphQLApiVisibilityType",
     "ListApiKeysPaginatorName",
     "ListDataSourcesPaginatorName",
     "ListFunctionsPaginatorName",
@@ -38,11 +42,14 @@ __all__ = (
     "ListResolversByFunctionPaginatorName",
     "ListResolversPaginatorName",
     "ListTypesPaginatorName",
+    "MergeTypeType",
     "OutputTypeType",
+    "OwnershipType",
     "RelationalDatabaseSourceTypeType",
     "ResolverKindType",
     "RuntimeNameType",
     "SchemaStatusType",
+    "SourceApiAssociationStatusType",
     "TypeDefinitionFormatType",
     "AppSyncServiceName",
     "ServiceName",
@@ -78,9 +85,11 @@ AuthenticationTypeType = Literal[
 AuthorizationTypeType = Literal["AWS_IAM"]
 ConflictDetectionTypeType = Literal["NONE", "VERSION"]
 ConflictHandlerTypeType = Literal["AUTOMERGE", "LAMBDA", "NONE", "OPTIMISTIC_CONCURRENCY"]
+DataSourceIntrospectionStatusType = Literal["FAILED", "PROCESSING", "SUCCESS"]
 DataSourceTypeType = Literal[
     "AMAZON_DYNAMODB",
     "AMAZON_ELASTICSEARCH",
+    "AMAZON_EVENTBRIDGE",
     "AMAZON_OPENSEARCH_SERVICE",
     "AWS_LAMBDA",
     "HTTP",
@@ -89,6 +98,8 @@ DataSourceTypeType = Literal[
 ]
 DefaultActionType = Literal["ALLOW", "DENY"]
 FieldLogLevelType = Literal["ALL", "ERROR", "NONE"]
+GraphQLApiTypeType = Literal["GRAPHQL", "MERGED"]
+GraphQLApiVisibilityType = Literal["GLOBAL", "PRIVATE"]
 ListApiKeysPaginatorName = Literal["list_api_keys"]
 ListDataSourcesPaginatorName = Literal["list_data_sources"]
 ListFunctionsPaginatorName = Literal["list_functions"]
@@ -96,13 +107,25 @@ ListGraphqlApisPaginatorName = Literal["list_graphql_apis"]
 ListResolversByFunctionPaginatorName = Literal["list_resolvers_by_function"]
 ListResolversPaginatorName = Literal["list_resolvers"]
 ListTypesPaginatorName = Literal["list_types"]
+MergeTypeType = Literal["AUTO_MERGE", "MANUAL_MERGE"]
 OutputTypeType = Literal["JSON", "SDL"]
+OwnershipType = Literal["CURRENT_ACCOUNT", "OTHER_ACCOUNTS"]
 RelationalDatabaseSourceTypeType = Literal["RDS_HTTP_ENDPOINT"]
 ResolverKindType = Literal["PIPELINE", "UNIT"]
 RuntimeNameType = Literal["APPSYNC_JS"]
 SchemaStatusType = Literal[
     "ACTIVE", "DELETING", "FAILED", "NOT_APPLICABLE", "PROCESSING", "SUCCESS"
 ]
+SourceApiAssociationStatusType = Literal[
+    "AUTO_MERGE_SCHEDULE_FAILED",
+    "DELETION_FAILED",
+    "DELETION_IN_PROGRESS",
+    "DELETION_SCHEDULED",
+    "MERGE_FAILED",
+    "MERGE_IN_PROGRESS",
+    "MERGE_SCHEDULED",
+    "MERGE_SUCCESS",
+]
 TypeDefinitionFormatType = Literal["JSON", "SDL"]
 AppSyncServiceName = Literal["appsync"]
 ServiceName = Literal[
@@ -120,6 +143,7 @@ ServiceName = Literal[
     "apigatewayv2",
     "appconfig",
     "appconfigdata",
+    "appfabric",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -134,10 +158,14 @@ ServiceName = Literal[
     "auditmanager",
     "autoscaling",
     "autoscaling-plans",
+    "b2bi",
     "backup",
     "backup-gateway",
     "backupstorage",
     "batch",
+    "bcm-data-exports",
+    "bedrock",
+    "bedrock-runtime",
     "billingconductor",
     "braket",
     "budgets",
@@ -148,16 +176,19 @@ ServiceName = Literal[
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "chime-sdk-voice",
+    "cleanrooms",
     "cloud9",
     "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
+    "cloudfront-keyvaluestore",
     "cloudhsm",
     "cloudhsmv2",
     "cloudsearch",
     "cloudsearchdomain",
     "cloudtrail",
+    "cloudtrail-data",
     "cloudwatch",
     "codeartifact",
     "codebuild",
@@ -165,6 +196,7 @@ ServiceName = Literal[
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
+    "codeguru-security",
     "codeguruprofiler",
     "codepipeline",
     "codestar",
@@ -183,12 +215,14 @@ ServiceName = Literal[
     "connectcases",
     "connectparticipant",
     "controltower",
+    "cost-optimization-hub",
     "cur",
     "customer-profiles",
     "databrew",
     "dataexchange",
     "datapipeline",
     "datasync",
+    "datazone",
     "dax",
     "detective",
     "devicefarm",
@@ -211,6 +245,7 @@ ServiceName = Literal[
     "ecs",
     "efs",
     "eks",
+    "eks-auth",
     "elastic-inference",
     "elasticache",
     "elasticbeanstalk",
@@ -220,6 +255,7 @@ ServiceName = Literal[
     "emr",
     "emr-containers",
     "emr-serverless",
+    "entityresolution",
     "es",
     "events",
     "evidently",
@@ -231,9 +267,9 @@ ServiceName = Literal[
     "forecast",
     "forecastquery",
     "frauddetector",
+    "freetier",
     "fsx",
     "gamelift",
-    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -250,7 +286,9 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector-scan",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -269,26 +307,31 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "kendra-ranking",
     "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
     "kinesis-video-signaling",
+    "kinesis-video-webrtc-storage",
     "kinesisanalytics",
     "kinesisanalyticsv2",
     "kinesisvideo",
     "kms",
     "lakeformation",
     "lambda",
+    "launch-wizard",
     "lex-models",
     "lex-runtime",
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-linux-subscriptions",
     "license-manager-user-subscriptions",
     "lightsail",
     "location",
@@ -298,9 +341,9 @@ ServiceName = Literal[
     "lookoutvision",
     "m2",
     "machinelearning",
-    "macie",
     "macie2",
     "managedblockchain",
+    "managedblockchain-query",
     "marketplace-catalog",
     "marketplace-entitlement",
     "marketplacecommerceanalytics",
@@ -309,9 +352,11 @@ ServiceName = Literal[
     "medialive",
     "mediapackage",
     "mediapackage-vod",
+    "mediapackagev2",
     "mediastore",
     "mediastore-data",
     "mediatailor",
+    "medical-imaging",
     "memorydb",
     "meteringmarketplace",
     "mgh",
@@ -325,6 +370,7 @@ ServiceName = Literal[
     "mturk",
     "mwaa",
     "neptune",
+    "neptunedata",
     "network-firewall",
     "networkmanager",
     "nimble",
@@ -335,8 +381,12 @@ ServiceName = Literal[
     "opsworks",
     "opsworkscm",
     "organizations",
+    "osis",
     "outposts",
     "panorama",
+    "payment-cryptography",
+    "payment-cryptography-data",
+    "pca-connector-ad",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -361,6 +411,7 @@ ServiceName = Literal[
     "redshift-data",
     "redshift-serverless",
     "rekognition",
+    "repostspace",
     "resiliencehub",
     "resource-explorer-2",
     "resource-groups",
@@ -382,6 +433,7 @@ ServiceName = Literal[
     "sagemaker-edge",
     "sagemaker-featurestore-runtime",
     "sagemaker-geospatial",
+    "sagemaker-metrics",
     "sagemaker-runtime",
     "savingsplans",
     "scheduler",
@@ -423,10 +475,14 @@ ServiceName = Literal[
     "textract",
     "timestream-query",
     "timestream-write",
+    "tnb",
     "transcribe",
     "transfer",
     "translate",
+    "trustedadvisor",
+    "verifiedpermissions",
     "voice-id",
+    "vpc-lattice",
     "waf",
     "waf-regional",
     "wafv2",
@@ -437,6 +493,7 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-thin-client",
     "workspaces-web",
     "xray",
 ]
@@ -468,16 +525,20 @@ RegionName = Literal[
     "ap-northeast-2",
     "ap-northeast-3",
     "ap-south-1",
+    "ap-south-2",
     "ap-southeast-1",
     "ap-southeast-2",
     "ap-southeast-3",
     "ca-central-1",
     "eu-central-1",
+    "eu-central-2",
     "eu-north-1",
     "eu-south-1",
+    "eu-south-2",
     "eu-west-1",
     "eu-west-2",
     "eu-west-3",
+    "me-central-1",
     "me-south-1",
     "sa-east-1",
     "us-east-1",
