@@ -31,18 +31,19 @@ Usage::
     list_types_paginator: ListTypesPaginator = client.get_paginator("list_types")
     ```
 """
+
 from typing import Generic, Iterator, TypeVar
 
 from botocore.paginate import PageIterator, Paginator
 
-from .literals import TypeDefinitionFormatType
+from .literals import GraphQLApiTypeType, OwnershipType, TypeDefinitionFormatType
 from .type_defs import (
     ListApiKeysResponseTypeDef,
     ListDataSourcesResponseTypeDef,
     ListFunctionsResponseTypeDef,
     ListGraphqlApisResponseTypeDef,
-    ListResolversByFunctionResponseTypeDef,
-    ListResolversResponseTypeDef,
+    ListResolversByFunctionResponsePaginatorTypeDef,
+    ListResolversResponsePaginatorTypeDef,
     ListTypesResponseTypeDef,
     PaginatorConfigTypeDef,
 )
@@ -120,7 +121,11 @@ class ListGraphqlApisPaginator(Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+        self,
+        *,
+        apiType: GraphQLApiTypeType = ...,
+        owner: OwnershipType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListGraphqlApisResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis.paginate)
@@ -136,7 +141,7 @@ class ListResolversPaginator(Paginator):
 
     def paginate(
         self, *, apiId: str, typeName: str, PaginationConfig: PaginatorConfigTypeDef = ...
-    ) -> _PageIterator[ListResolversResponseTypeDef]:
+    ) -> _PageIterator[ListResolversResponsePaginatorTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListResolvers.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listresolverspaginator)
@@ -151,7 +156,7 @@ class ListResolversByFunctionPaginator(Paginator):
 
     def paginate(
         self, *, apiId: str, functionId: str, PaginationConfig: PaginatorConfigTypeDef = ...
-    ) -> _PageIterator[ListResolversByFunctionResponseTypeDef]:
+    ) -> _PageIterator[ListResolversByFunctionResponsePaginatorTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listresolversbyfunctionpaginator)
